/* This file was generated by syncqt. */
#ifndef QT_QTGRPCQUICK_VERSION_H
#define QT_QTGRPCQUICK_VERSION_H

#define QTGRPCQUICK_VERSION_STR "6.12.0"

#define QTGRPCQUICK_VERSION 0x0601200

#endif // QT_QTGRPCQUICK_VERSION_H
